@@ -67,22 +67,32 @@ class Form:
         self.unicode_mode = unicode_mode
 
     security.declareProtected('View', 'test_form')
-    def test_form(self):
+    def test_form(self, context=None, bad_fields=[]):
+        all_invalid_fields = set(['name', 'action'])
+        all_invalid_fields.update(bad_fields)
         try:
             form_fields = self.get_fields()
         except AttributeError:
             raise ValueError(u"Form contains broken fields.")
         errors = []
         for field in form_fields:
+            if field.id in all_invalid_fields:
+                errors.append(
+                    (u"Form field '%s' have an identifier that will conflict "
+                     u"with the behavior of the form.") % (field.id))
             for identifier, expression in field.tales.items():
                 if not expression:
                     continue
                 try:
+                    if context is not None:
+                        field = field.__of__(context)
                     field.get_value(identifier)
                 except Exception as error:
                     errors.append(
-                        u"Form field '%s' contains a broken TALES expression for option '%s': %s: %s." % (
-                            field.id, identifier, error.__class__.__name__, str(error)))
+                        (u"Form field '%s' contains a broken TALES "
+                         u"expression for option '%s': %s: %s.") % (
+                            field.id, identifier,
+                            error.__class__.__name__, str(error)))
         if errors:
             raise ValueError(*errors)
         return True
@@ -788,7 +798,7 @@ class ZMIForm(ObjectManager, PropertyManager, RoleManager, Item, Form):
         raise FieldDisabledError("Field %s disabled" % id, field)
 
     security.declareProtected('Change Formulator Forms', 'manage_addField')
-    def manage_addField(self, id, title, fieldname, REQUEST=None):
+    def manage_addField(self, id, title, fieldname, REQUEST=None, **options):
         """Add a new field to the form.
         id        -- the id of the field to add
         title     -- the title of the field to add; this will be used in
@@ -805,7 +815,7 @@ class ZMIForm(ObjectManager, PropertyManager, RoleManager, Item, Form):
         # get the field class we want to add
         field_class = FieldRegistry.get_field_class(fieldname)
         # create field instance
-        field = field_class(id, title=title, description="")
+        field = field_class(id, title=title, **options)
         # add the field to the form
         id = self._setObject(id, field)
         # respond to add_and_edit button if necessary
